ComposableObject

Trait ComposableObject 

pub trait ComposableObject: GraphQLTypeAsync + Default
where Self::Context: Sync, Self::TypeInfo: Sync,
{ // Required method fn fields() -> &'static [&'static str]; }
Object types that you want to compose into one must implement this trait. Use composable_object to implement it.

Required Methods

fn fields() -> &'static [&'static str]

Returns a list of fields that exist on this object type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors